Module api_key_scope

Module api_key_scope 

Enums

ApiKeyScope
ApiKeyScope : A permission granted to an API key. The * scope grants every permission. The players:read-details scope grants the access available with players:read and also permits access to linked Discord user IDs. A permission granted to an API key. The * scope grants every permission. The players:read-details scope grants the access available with players:read and also permits access to linked Discord user IDs.