pub enum ApiKeyScope {
Show 15 variants
Star,
ApiKeysColonRead,
ApiKeysColonWrite,
CrawlsColonRead,
CrawlsColonWrite,
EmojisColonRead,
EmojisColonWrite,
PatchNotesColonRead,
PatchNotesColonWrite,
PlayersColonRead,
PlayersColonReadDetails,
PlayersColonWrite,
PunishmentsColonRead,
PunishmentsColonWrite,
StreamColonRead,
}Expand description
ApiKeyScope : A permission granted to an API key. The * scope grants every permission. The players:read-details scope grants the access available with players:read and also permits access to linked Discord user IDs.
A permission granted to an API key. The * scope grants every permission. The players:read-details scope grants the access available with players:read and also permits access to linked Discord user IDs.
Variants
Star
ApiKeysColonRead
ApiKeysColonWrite
CrawlsColonRead
CrawlsColonWrite
EmojisColonRead
EmojisColonWrite
PatchNotesColonRead
PatchNotesColonWrite
PlayersColonRead
PlayersColonReadDetails
PlayersColonWrite
PunishmentsColonRead
PunishmentsColonWrite
StreamColonRead