pub struct CreateApiKeyRequest {
pub name: String,
pub scopes: HashSet<Scopes>,
pub expires_at: Option<Option<DateTime<FixedOffset>>>,
pub player_id: Option<Option<Uuid>>,
}Fields
name: StringThe human-readable name of the API key.
scopes: HashSet<Scopes>The scopes required for the new API key. The API key used to make the request must be authorized to delegate each requested scope.
expires_at: Option<Option<DateTime<FixedOffset>>>The date and time at which the API key expires, or null if it does not expire.
player_id: Option<Option<Uuid>>The player linked to this API key, or null if the key is not linked to a player.
Implementations