pub struct FriendRequestRemovedEvent {
pub data: Box<FriendRequestRemovedEventData>,
}Expand description
FriendRequestRemovedEvent : Represents an event indicating that a friend request was removed. Requires the stream:read and players:read scopes to receive this event.
Fields
data: Box<FriendRequestRemovedEventData>Implementations
Sourceimpl FriendRequestRemovedEvent
impl FriendRequestRemovedEvent
Sourcepub fn new(data: FriendRequestRemovedEventData) -> FriendRequestRemovedEvent
pub fn new(data: FriendRequestRemovedEventData) -> FriendRequestRemovedEvent
Represents an event indicating that a friend request was removed. Requires the stream:read and players:read scopes to receive this event.