pub struct PatchNoteCreatedEvent {
pub data: Box<PatchNoteCreatedEventData>,
}Expand description
PatchNoteCreatedEvent : Represents an event indicating that a patch note was created. Requires the stream:read and patch-notes:read scopes to receive this event.
Fields
data: Box<PatchNoteCreatedEventData>Implementations
Sourceimpl PatchNoteCreatedEvent
impl PatchNoteCreatedEvent
Sourcepub fn new(data: PatchNoteCreatedEventData) -> PatchNoteCreatedEvent
pub fn new(data: PatchNoteCreatedEventData) -> PatchNoteCreatedEvent
Represents an event indicating that a patch note was created. Requires the stream:read and patch-notes:read scopes to receive this event.