pub struct PatchNoteDeletedEvent {
pub data: Box<PatchNoteDeletedEventData>,
}Expand description
PatchNoteDeletedEvent : Represents an event indicating that a patch note was deleted. Requires the stream:read and patch-notes:read scopes to receive this event.
Fields
data: Box<PatchNoteDeletedEventData>Implementations
Sourceimpl PatchNoteDeletedEvent
impl PatchNoteDeletedEvent
Sourcepub fn new(data: PatchNoteDeletedEventData) -> PatchNoteDeletedEvent
pub fn new(data: PatchNoteDeletedEventData) -> PatchNoteDeletedEvent
Represents an event indicating that a patch note was deleted. Requires the stream:read and patch-notes:read scopes to receive this event.