pub struct UpdateApiKeyByIdRequest {
pub name: Option<String>,
pub scopes: Option<HashSet<Scopes>>,
pub expires_at: Option<Option<DateTime<FixedOffset>>>,
pub player_id: Option<Option<Uuid>>,
}Fields
name: Option<String>The human-readable name of the API key.
scopes: Option<HashSet<Scopes>>The scopes to grant to the API key. The API key used to make the request must be authorized to delegate each requested scope.
expires_at: Option<Option<DateTime<FixedOffset>>>The date and time at which the API key expires, or null if it does not expire.
player_id: Option<Option<Uuid>>The player linked to this API key, or null if the key is not linked to a player.
Implementations
Sourceimpl UpdateApiKeyByIdRequest
impl UpdateApiKeyByIdRequest
pub fn new() -> UpdateApiKeyByIdRequest