Enums
- ApiKey
Scope - ApiKeyScope : A permission granted to an API key. The
*scope grants every permission. Theplayers:read-detailsscope grants the access available withplayers:readand also permits access to linked Discord user IDs. A permission granted to an API key. The*scope grants every permission. Theplayers:read-detailsscope grants the access available withplayers:readand also permits access to linked Discord user IDs.